@@ -28,15 +28,16 @@ ggv_prefs_dialog_apply(GgvPrefsDialog *dlg)
 
         gtk_gs_defaults_set_interpreter_cmd
                 (g_strdup(gtk_entry_get_text(GTK_ENTRY(dlg->gs))));
-        gtk_gs_defaults_set_scan_pdf_cmd
-                (g_strdup(gtk_entry_get_text(GTK_ENTRY(dlg->scan_pdf))));
+        gtk_gs_defaults_set_convert_pdf_cmd
+                (g_strdup(gtk_entry_get_text(GTK_ENTRY(dlg->convert_pdf))));
         gtk_gs_defaults_set_ungzip_cmd
                 (g_strdup(gtk_entry_get_text (GTK_ENTRY (dlg->unzip))));
         gtk_gs_defaults_set_unbzip2_cmd
                 (g_strdup(gtk_entry_get_text (GTK_ENTRY (dlg->unbzip2))));
         gtk_gs_defaults_set_alpha_parameters
                 (g_strdup(gtk_entry_get_text (GTK_ENTRY (dlg->alpha_params))));
-
+        gtk_gs_defaults_set_scroll_step
+                (gtk_spin_button_get_value(GTK_SPIN_BUTTON(dlg->scroll_step)));
         if(ggv_print_cmd)
                 g_free(ggv_print_cmd);
         ggv_print_cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(dlg->print)));
@@ -73,6 +74,14 @@ ggv_prefs_dialog_apply(GgvPrefsDialog *dlg)
                 }
         }
 
+        active = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(dlg->auto_fit))));
+        for(i = 0; i <= ggv_max_auto_fit_modes; i++){
+                if(active == dlg->auto_fit_choice[i]) {
+                        gtk_gs_defaults_set_zoom_mode(i);
+                        break;
+                }
+        }
+
         gtk_gs_defaults_set_respect_eof(GTK_TOGGLE_BUTTON(dlg->respect_eof)->active);
         gtk_gs_defaults_set_watch_doc(GTK_TOGGLE_BUTTON(dlg->watch)->active);
         gtk_gs_defaults_set_antialiased(GTK_TOGGLE_BUTTON(dlg->aa)->active);
@@ -94,6 +103,7 @@ ggv_prefs_dialog_apply(GgvPrefsDialog *dlg)
         ggv_menubar = GTK_TOGGLE_BUTTON(dlg->mbar)->active;
         ggv_statusbar = GTK_TOGGLE_BUTTON(dlg->sbar)->active;
         ggv_autojump = GTK_TOGGLE_BUTTON(dlg->auto_jump)->active;
+        ggv_pageflip = GTK_TOGGLE_BUTTON(dlg->page_flip)->active;
         ggv_right_panel = GTK_TOGGLE_BUTTON(dlg->right_panel)->active;
 
         gtk_gs_defaults_save();
@@ -188,6 +198,10 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
         gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->units),
                                     ggv_unit_index);
 
+        /* set auto-fit mode */
+        gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->auto_fit),
+                                    gtk_gs_defaults_get_zoom_mode());
+
         /* set default size */
         i = gtk_gs_defaults_get_size();
         gtk_option_menu_set_history(GTK_OPTION_MENU(dlg->size), i);
@@ -234,6 +248,8 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                                      ggv_save_geometry);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->auto_jump),
                                      ggv_autojump);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->page_flip),
+                                     ggv_pageflip);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dlg->right_panel),
                                      ggv_right_panel);
 
@@ -243,9 +259,9 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
         gtk_entry_set_text(GTK_ENTRY(dlg->alpha_params),
                            gtk_gs_defaults_get_alpha_parameters());
 	gtk_entry_set_position(GTK_ENTRY(dlg->alpha_params), 0);
-        gtk_entry_set_text(GTK_ENTRY(dlg->scan_pdf),
-                           gtk_gs_defaults_get_scan_pdf_cmd());
-	gtk_entry_set_position(GTK_ENTRY(dlg->scan_pdf), 0);
+        gtk_entry_set_text(GTK_ENTRY(dlg->convert_pdf),
+                           gtk_gs_defaults_get_convert_pdf_cmd());
+	gtk_entry_set_position(GTK_ENTRY(dlg->convert_pdf), 0);
         gtk_entry_set_text(GTK_ENTRY(dlg->unzip),
                            gtk_gs_defaults_get_ungzip_cmd());
 	gtk_entry_set_position(GTK_ENTRY(dlg->unzip), 0);
@@ -256,7 +272,9 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                            ggv_print_cmd);
 	gtk_entry_set_position(GTK_ENTRY(dlg->print), 0);
 
-	gtk_window_position(GTK_WINDOW(dlg), GTK_WIN_POS_MOUSE);
+        gtk_spin_button_set_value(GTK_SPIN_BUTTON(dlg->scroll_step),
+                                  gtk_gs_defaults_get_scroll_step());
+	gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_MOUSE);
 
         gtk_widget_grab_default(dlg->cancel);
 
@@ -290,10 +308,10 @@ GtkWidget *
 ggv_prefs_dialog_new()
 {
         static const gchar *tbstyle_labels[] = {
-                N_("Use GNOME defaults"),
-                N_("Show both icons and text"),
-                N_("Show only icons"),
-                N_("Show only text")
+                N_("_Use GNOME defaults"),
+                N_("Show _both icons and text"),
+                N_("Show only _icons"),
+                N_("Show only t_ext")
         };
 
         GgvPrefsDialog *dlg;
@@ -304,6 +322,7 @@ ggv_prefs_dialog_new()
         GSList *tbstyle_group = NULL;
         GtkAccelGroup *dlg_accel_group;
         GClosure *closure;
+        GtkObject *adj;
 
         dlg = GGV_PREFS_DIALOG(g_object_new(GGV_TYPE_PREFS_DIALOG, NULL));
         widget = GTK_WIDGET(dlg);
@@ -336,12 +355,6 @@ ggv_prefs_dialog_new()
         gtk_accel_group_connect(dlg_accel_group, GDK_Escape, 0, 0, closure);
         gtk_window_add_accel_group(GTK_WINDOW(dlg), dlg_accel_group);
 
-        GTK_WIDGET_SET_FLAGS(dlg->cancel, GTK_CAN_DEFAULT);
-        gtk_widget_show(dlg->cancel);
-        g_signal_connect(G_OBJECT(dlg->cancel), "clicked",
-                         G_CALLBACK(ggv_prefs_dialog_cancel_clicked), dlg);
-        gtk_box_pack_start(GTK_BOX(bbox), dlg->cancel, 0, FALSE, FALSE);
-
         dlg->apply = gtk_button_new_from_stock(GTK_STOCK_APPLY);
         GTK_WIDGET_SET_FLAGS(dlg->apply, GTK_CAN_DEFAULT);
         gtk_widget_show(dlg->apply);
@@ -349,6 +362,12 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(ggv_prefs_dialog_apply_clicked), dlg);
         gtk_box_pack_start(GTK_BOX(bbox), dlg->apply, 0, FALSE, FALSE);
 
+        GTK_WIDGET_SET_FLAGS(dlg->cancel, GTK_CAN_DEFAULT);
+        gtk_widget_show(dlg->cancel);
+        g_signal_connect(G_OBJECT(dlg->cancel), "clicked",
+                         G_CALLBACK(ggv_prefs_dialog_cancel_clicked), dlg);
+        gtk_box_pack_start(GTK_BOX(bbox), dlg->cancel, 0, FALSE, FALSE);
+
         dlg->ok = gtk_button_new_from_stock(GTK_STOCK_OK);
         GTK_WIDGET_SET_FLAGS(dlg->ok, GTK_CAN_DEFAULT);
         gtk_widget_show(dlg->ok);
@@ -361,19 +380,20 @@ ggv_prefs_dialog_new()
         dlg->zoom_choice = g_new0(GtkWidget *, ggv_max_zoom_levels + 1);
         dlg->orientation_choice = g_new0(GtkWidget *, ggv_max_orientation_labels + 1);
         dlg->unit_choice = g_new0(GtkWidget *, ggv_max_unit_labels + 1);
+        dlg->auto_fit_choice = g_new0(GtkWidget *, ggv_max_auto_fit_modes + 1);
 
         /* Document page */
-        table = gtk_table_new(2, 10, FALSE);
+        table = gtk_table_new(10, 2, FALSE);
 
         /* zoom choice menu */
-        label = gtk_label_new(_("Default Zoom:"));
+        label = gtk_label_new_with_mnemonic(_("_Default Zoom:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         gtk_widget_show(label);
@@ -386,7 +406,7 @@ ggv_prefs_dialog_new()
         for(i = 0; i <= ggv_max_zoom_levels; i++) {
                 dlg->zoom_choice[i] = gtk_menu_item_new_with_label(ggv_zoom_level_names[i]);
                 gtk_widget_show(dlg->zoom_choice[i]);
-                gtk_menu_append(GTK_MENU(menu), dlg->zoom_choice[i]);
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->zoom_choice[i]);
                 g_signal_connect(G_OBJECT(dlg->zoom_choice[i]),
                                  "activate",
                                  G_CALLBACK(prefs_dlg_change_handler), dlg);
@@ -396,18 +416,51 @@ ggv_prefs_dialog_new()
         gtk_table_attach(GTK_TABLE(table), dlg->zoom,
                          1, 2, 0, 1,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->zoom);
 
-        /* units choice menu */
-        label = gtk_label_new(_("Coordinate units:"));
+        /* auto-fit choice menu */
+        label = gtk_label_new_with_mnemonic(_("A_uto-fit mode:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 1, 2,
                          GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+
+        gtk_widget_show(label);
+        dlg->auto_fit = gtk_option_menu_new();
+        gtk_widget_show(dlg->auto_fit);
+        menu = gtk_menu_new();
+        for(i = 0; i <= ggv_max_auto_fit_modes; i++) {
+                dlg->auto_fit_choice[i] = gtk_menu_item_new_with_label(_(ggv_auto_fit_modes[i]));
+                gtk_widget_show(dlg->auto_fit_choice[i]);
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->auto_fit_choice[i]);
+                g_signal_connect(G_OBJECT(dlg->auto_fit_choice[i]),
+                                 "activate",
+                                 G_CALLBACK(prefs_dlg_change_handler), dlg);
+        }
+        gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->auto_fit), menu);
+
+        gtk_table_attach(GTK_TABLE(table), dlg->auto_fit,
+                         1, 2, 1, 2,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->auto_fit);
+
+        /* units choice menu */
+       label = gtk_label_new_with_mnemonic(_("_Coordinate units:"));
+        gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+        gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
+
+        gtk_table_attach(GTK_TABLE(table), label,
+                         0, 1, 2, 3,
+                         GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         gtk_widget_show(label);
@@ -417,7 +470,7 @@ ggv_prefs_dialog_new()
         for(i = 0; i <= ggv_max_unit_labels; i++) {
                 dlg->unit_choice[i] = gtk_menu_item_new_with_label(_(ggv_unit_labels[i]));
                 gtk_widget_show(dlg->unit_choice[i]);
-                gtk_menu_append(GTK_MENU(menu), dlg->unit_choice[i]);
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->unit_choice[i]);
                 g_signal_connect(G_OBJECT(dlg->unit_choice[i]),
                                  "activate",
                                  G_CALLBACK(prefs_dlg_change_handler), dlg);
@@ -425,19 +478,20 @@ ggv_prefs_dialog_new()
         gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->units), menu);
 
         gtk_table_attach(GTK_TABLE(table), dlg->units,
-                         1, 2, 1, 2,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         1, 2, 2, 3,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->units);
 
         /* size choice menu */
-        label = gtk_label_new(_("Fallback page size:"));
+        label = gtk_label_new_with_mnemonic(_("_Fallback page size:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
         gtk_table_attach(GTK_TABLE(table), label,
-                         0, 1, 2, 3,
+                         0, 1, 3, 4,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
         dlg->size = gtk_option_menu_new();
@@ -447,7 +501,7 @@ ggv_prefs_dialog_new()
         for(i = 0; papersizes[i].name != NULL; i++) {
                 dlg->size_choice[i] = gtk_menu_item_new_with_label(papersizes[i].name);
                 gtk_widget_show(dlg->size_choice[i]);
-                gtk_menu_append(GTK_MENU(menu), dlg->size_choice[i]);
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->size_choice[i]);
                 g_signal_connect(G_OBJECT(dlg->size_choice[i]),
                                  "activate",
                                  G_CALLBACK(prefs_dlg_change_handler), dlg);
@@ -455,29 +509,30 @@ ggv_prefs_dialog_new()
         gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->size), menu);
 
         gtk_table_attach(GTK_TABLE(table), dlg->size,
-                         1, 2, 2, 3,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         1, 2, 3, 4,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->size);
 
         /* override media size */
-        dlg->override_size = gtk_check_button_new_with_label(_("Override document size"));
+        dlg->override_size = gtk_check_button_new_with_mnemonic (_("Override _document size"));
         gtk_table_attach(GTK_TABLE(table), dlg->override_size,
-                         0, 2, 3, 4,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         0, 2, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->override_size), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->override_size);
 
         /* orientation choice menu */
-        label = gtk_label_new(_("Fallback media orientation:"));
+        label = gtk_label_new_with_mnemonic(_("Fallback _media orientation:"));
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
         gtk_table_attach(GTK_TABLE(table), label,
-                         0, 1, 4, 5,
+                         0, 1, 5, 6,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
 
@@ -487,7 +542,7 @@ ggv_prefs_dialog_new()
         for(i = 0; i <= ggv_max_orientation_labels; i++) {
                 dlg->orientation_choice[i] = gtk_menu_item_new_with_label(_(ggv_orientation_labels[i]));
                 gtk_widget_show(dlg->orientation_choice[i]);
-                gtk_menu_append(GTK_MENU(menu), dlg->orientation_choice[i]);
+                gtk_menu_shell_append(GTK_MENU_SHELL(menu), dlg->orientation_choice[i]);
                 g_signal_connect(G_OBJECT(dlg->orientation_choice[i]),
                                  "activate",
                                  G_CALLBACK(prefs_dlg_change_handler), dlg);
@@ -495,111 +550,101 @@ ggv_prefs_dialog_new()
         gtk_option_menu_set_menu(GTK_OPTION_MENU(dlg->orientation), menu);
 
         gtk_table_attach(GTK_TABLE(table), dlg->orientation,
-                         1, 2, 4, 5,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         1, 2, 5, 6,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_label_set_mnemonic_widget(GTK_LABEL (label), dlg->orientation);
 
         /* override orientation media */
-        dlg->override_orientation = gtk_check_button_new_with_label(_("Override document orientation"));
+        dlg->override_orientation = gtk_check_button_new_with_mnemonic (_("O_verride document orientation"));
         gtk_table_attach(GTK_TABLE(table), dlg->override_orientation,
-                         0, 2, 5, 6,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         0, 2, 6, 7,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->override_orientation), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->override_orientation);
 
         /* antialiasing */
-        dlg->aa = gtk_check_button_new_with_label(_("Antialiasing"));
+        dlg->aa = gtk_check_button_new_with_mnemonic (_("A_ntialiasing"));
         gtk_table_attach(GTK_TABLE(table), dlg->aa,
-                         0, 2, 6, 7,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         0, 2, 7, 8,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->aa), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->aa);
 
         /* respect EOF */
-        dlg->respect_eof = gtk_check_button_new_with_label(_("Respect EOF comments"));
+        dlg->respect_eof = gtk_check_button_new_with_mnemonic (_("_Respect EOF comments"));
         gtk_table_attach(GTK_TABLE(table), dlg->respect_eof,
-                         0, 2, 7, 8,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         0, 2, 8, 9,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->respect_eof), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->respect_eof);
 
         /* watch file */
-        dlg->watch = gtk_check_button_new_with_label(_("Watch file"));
+        dlg->watch = gtk_check_button_new_with_mnemonic (_("_Watch file"));
         gtk_table_attach(GTK_TABLE(table), dlg->watch,
-                         0, 2, 8, 9,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         0, 2, 9, 10,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->watch), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->watch);
 
-        /* show previously visible part */
-        dlg->show_scroll_rect = gtk_check_button_new_with_label(_("Outline last visible part when scrolling"));
-        gtk_table_attach(GTK_TABLE(table), dlg->show_scroll_rect,
-                         0, 2, 9, 10,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-        g_signal_connect(G_OBJECT(dlg->show_scroll_rect), "clicked",
-                         G_CALLBACK(prefs_dlg_change_handler), dlg);
-        gtk_widget_show(dlg->show_scroll_rect);
-
         label = gtk_label_new(_("Document"));
         gtk_widget_show(label);
         gtk_widget_show(table);
         gtk_notebook_append_page(GTK_NOTEBOOK(dlg->notebook), table, label);
 
         /* Layout page */
-        table = gtk_table_new(8, 1, FALSE);
+        table = gtk_table_new(7, 1, FALSE);
 
         /* show side panel */
-        dlg->sidebar = gtk_check_button_new_with_label(_("Show side panel"));
+        dlg->sidebar = gtk_check_button_new_with_mnemonic(_("_Show side panel"));
         gtk_table_attach(GTK_TABLE(table), dlg->sidebar,
                          0, 1, 0, 1,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->sidebar), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->sidebar);
 
-        dlg->right_panel = gtk_check_button_new_with_label(_("Put side panel in Nautilus on the right"));
+        dlg->right_panel = gtk_check_button_new_with_mnemonic(_("_Put side panel on the right-hand side"));
         gtk_table_attach(GTK_TABLE(table), dlg->right_panel,
                          0, 1, 1, 2,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->right_panel), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->right_panel);
 
         /* show menubar */
-        dlg->mbar = gtk_check_button_new_with_label(_("Show menubar"));
+        dlg->mbar = gtk_check_button_new_with_mnemonic(_("Show _menubar"));
         gtk_table_attach(GTK_TABLE(table), dlg->mbar,
                          0, 1, 2, 3,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->mbar), "clicked",
                            G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->mbar);
 	/* show toolbar */
-        dlg->toolbar = gtk_check_button_new_with_label(_("Show toolbar"));
+        dlg->toolbar = gtk_check_button_new_with_mnemonic(_("Show _toolbar"));
         gtk_table_attach(GTK_TABLE(table), dlg->toolbar,
                          0, 1, 3, 4,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->toolbar), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
@@ -614,12 +659,12 @@ ggv_prefs_dialog_new()
         gtk_table_attach(GTK_TABLE(table), frame,
                          0, 1, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         for(i = 0; i < GGV_TOOLBAR_STYLE_LAST; i++) {
-                dlg->tbstyle[i] = gtk_radio_button_new_with_label(tbstyle_group,
+                dlg->tbstyle[i] = gtk_radio_button_new_with_mnemonic(tbstyle_group,
                                                                   _(tbstyle_labels[i]));
-                tbstyle_group = gtk_radio_button_group(GTK_RADIO_BUTTON(dlg->tbstyle[i]));
+                tbstyle_group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(dlg->tbstyle[i]));
                 g_signal_connect(G_OBJECT(dlg->tbstyle[i]), "toggled",
                                  G_CALLBACK(prefs_dlg_change_handler), dlg);
                 gtk_widget_show(dlg->tbstyle[i]);
@@ -628,147 +673,206 @@ ggv_prefs_dialog_new()
         }
                                    
         /* show statusbar */
-        dlg->sbar = gtk_check_button_new_with_label(_("Show statusbar"));
+        dlg->sbar = gtk_check_button_new_with_mnemonic(_("Show s_tatusbar"));
         gtk_table_attach(GTK_TABLE(table), dlg->sbar,
                          0, 1, 5, 6,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->sbar), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->sbar);
 
         /* save geometry */
-        dlg->savegeo = gtk_check_button_new_with_label(_("Save geometry"));
+        dlg->savegeo = gtk_check_button_new_with_mnemonic(_("Save _geometry"));
         gtk_table_attach(GTK_TABLE(table), dlg->savegeo,
                          0, 1, 6, 7,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         g_signal_connect(G_OBJECT(dlg->savegeo), "clicked",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->savegeo);
-        /* auto jump to beginning of page */
-        dlg->auto_jump= gtk_check_button_new_with_label(_("Jump to beginning of page"));
-        gtk_table_attach(GTK_TABLE(table), dlg->auto_jump,
-                         0, 1, 7, 8,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-        g_signal_connect(G_OBJECT(dlg->auto_jump), "clicked",
-                         G_CALLBACK(prefs_dlg_change_handler), dlg);
-        gtk_widget_show(dlg->auto_jump);
 
         label = gtk_label_new(_("Layout"));
         gtk_widget_show(label);
         gtk_widget_show(table);
         gtk_notebook_append_page(GTK_NOTEBOOK(dlg->notebook), table, label);
 
+
+        /* Navigation page */
+        table = gtk_table_new(4, 2, FALSE);
+
+        /* auto jump to beginning of page */
+        dlg->auto_jump = gtk_check_button_new_with_mnemonic(_("_Jump to beginning of page"));
+        gtk_table_attach(GTK_TABLE(table), dlg->auto_jump,
+                         0, 2, 0, 1,
+                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        g_signal_connect(G_OBJECT(dlg->auto_jump), "clicked",
+                         G_CALLBACK(prefs_dlg_change_handler), dlg);
+        gtk_widget_show(dlg->auto_jump);
+        /* automatically flip pages */
+        dlg->page_flip = gtk_check_button_new_with_mnemonic(_("Automatically _flip pages"));
+        gtk_table_attach(GTK_TABLE(table), dlg->page_flip,
+                         0, 2, 1, 2,
+                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        g_signal_connect(G_OBJECT(dlg->page_flip), "clicked",
+                         G_CALLBACK(prefs_dlg_change_handler), dlg);
+        gtk_widget_show(dlg->page_flip);
+
+        /* show previously visible part */
+        dlg->show_scroll_rect = gtk_check_button_new_with_mnemonic(_("Outline _last visible part when scrolling"));
+        gtk_table_attach(GTK_TABLE(table), dlg->show_scroll_rect,
+                         0, 2, 9, 10,
+                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        g_signal_connect(G_OBJECT(dlg->show_scroll_rect), "clicked",
+                         G_CALLBACK(prefs_dlg_change_handler), dlg);
+        gtk_widget_show(dlg->show_scroll_rect);
+
+        /* scroll step */
+        adj = gtk_adjustment_new(0.0, 0.0, 1.0, 0.01, 0.1, 0.1);
+        dlg->scroll_step = gtk_spin_button_new(GTK_ADJUSTMENT(adj),
+                                               0.01, 2);
+        label = gtk_label_new_with_mnemonic(_("Amount of _visible area to scroll"));  
+        gtk_table_attach(GTK_TABLE(table), label,
+                         0, 1, 2, 3,
+                         GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        gtk_table_attach(GTK_TABLE(table), dlg->scroll_step,
+                         1, 2, 2, 3,
+                         GTK_SHRINK | GTK_FILL | GTK_EXPAND,
+                         GTK_SHRINK | GTK_FILL,
+                         GNOME_PAD_SMALL, GNOME_PAD_SMALL);
+        g_signal_connect(G_OBJECT(dlg->scroll_step), "value-changed",
+                         G_CALLBACK(prefs_dlg_change_handler), dlg);
+        gtk_widget_show(dlg->scroll_step);
+        gtk_widget_show(label);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->scroll_step);
+
+        label = gtk_label_new(_("Navigation"));
+        gtk_widget_show(label);
+        gtk_widget_show(table);
+        gtk_notebook_append_page(GTK_NOTEBOOK(dlg->notebook), table, label);
+
         /* GhostScript page */
-        table = gtk_table_new(2, 4, FALSE);
+        table = gtk_table_new(4, 2, FALSE);
 
         /* interpreter */
-        label = gtk_label_new(_("Interpreter:"));
+        label = gtk_label_new_with_mnemonic(_("_Interpreter:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
         dlg->gs = gtk_entry_new();
         gtk_table_attach(GTK_TABLE(table), dlg->gs,
                          1, 2, 0, 1,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 	g_signal_connect(G_OBJECT(dlg->gs), "activate",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	g_signal_connect(G_OBJECT(dlg->gs), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->gs);
-        /* interpreter */
-        label = gtk_label_new(_("Antialiasing:"));
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->gs);
+
+        /* antialiasing */
+        label = gtk_label_new_with_mnemonic(_("A_ntialiasing:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 1, 2,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
         dlg->alpha_params = gtk_entry_new();
         gtk_table_attach(GTK_TABLE(table), dlg->alpha_params,
                          1, 2, 1, 2,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 	g_signal_connect(G_OBJECT(dlg->alpha_params), "activate",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	g_signal_connect(G_OBJECT(dlg->alpha_params), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->alpha_params);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->alpha_params);
+
         /* scan PDF command */
-        label = gtk_label_new(_("Scan PDF:"));
+        label = gtk_label_new_with_mnemonic(_("Convert _PDF to PS:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 2, 3,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
-        dlg->scan_pdf = gtk_entry_new();
-        gtk_table_attach(GTK_TABLE(table), dlg->scan_pdf,
+        dlg->convert_pdf = gtk_entry_new();
+        gtk_table_attach(GTK_TABLE(table), dlg->convert_pdf,
                          1, 2, 2, 3,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	g_signal_connect(G_OBJECT(dlg->scan_pdf), "activate",
+	g_signal_connect(G_OBJECT(dlg->convert_pdf), "activate",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
-	g_signal_connect(G_OBJECT(dlg->scan_pdf), "changed",
+	g_signal_connect(G_OBJECT(dlg->convert_pdf), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
-        gtk_widget_show(dlg->scan_pdf);
+        gtk_widget_show(dlg->convert_pdf);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->convert_pdf);
 
 	/* unzip command: gzip */
-        label = gtk_label_new(_("Gzip:"));
+        label = gtk_label_new_with_mnemonic(_("_Gzip:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 3, 4,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
         dlg->unzip = gtk_entry_new();
         gtk_table_attach(GTK_TABLE(table), dlg->unzip,
                          1, 2, 3, 4,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 	g_signal_connect(G_OBJECT(dlg->unzip), "activate",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	g_signal_connect(G_OBJECT(dlg->unzip), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	gtk_widget_show(dlg->unzip);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->unzip);
 
 	/* unzip command: bzip2 */
-        label = gtk_label_new(_("Bzip2:"));
+        label = gtk_label_new_with_mnemonic(_("_Bzip2:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 4, 5,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
         dlg->unbzip2 = gtk_entry_new();
         gtk_table_attach(GTK_TABLE(table), dlg->unbzip2,
                          1, 2, 4, 5,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 	g_signal_connect(G_OBJECT(dlg->unbzip2), "activate",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	g_signal_connect(G_OBJECT(dlg->unbzip2), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	gtk_widget_show(dlg->unbzip2);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->unbzip2);
 
         label = gtk_label_new(_("Ghostscript"));
         gtk_widget_show(label);
@@ -779,24 +883,25 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(1, 2, FALSE);
 
         /* print command */
-        label = gtk_label_new(_("Print command:"));
+        label = gtk_label_new_with_mnemonic(_("_Print command:"));
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
                          GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
         gtk_widget_show(label);
         dlg->print = gtk_entry_new();
         gtk_table_attach(GTK_TABLE(table), dlg->print,
                          1, 2, 0, 1,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-                         GTK_EXPAND | GTK_SHRINK | GTK_FILL,
+                         GTK_SHRINK | GTK_FILL,
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 	g_signal_connect(G_OBJECT(dlg->print), "activate",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
 	g_signal_connect(G_OBJECT(dlg->print), "changed",
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->print);
+        gtk_label_set_mnemonic_widget(GTK_LABEL(label), dlg->print);
 
         label = gtk_label_new(_("Printing"));
         gtk_widget_show(label);
