@@ -127,6 +127,8 @@ The DONE message indicates that ghostscript has finished processing.
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <stdio.h>
+#include <math.h>
+
 #include "gtkgs.h"
 #include "ggvutils.h"
 #include "ps.h"
@@ -348,6 +350,8 @@ gtk_gs_init (GtkGS *gs)
         gs->respect_eof = gtk_gs_defaults_get_respect_eof();
         gs->watch_doc = gtk_gs_defaults_get_watch_doc();
         gs->show_scroll_rect = gtk_gs_defaults_get_show_scroll_rect();
+        gs->scroll_step = gtk_gs_defaults_get_scroll_step();
+        gs->zoom_mode = gtk_gs_defaults_get_zoom_mode();
 
         gs->scroll_start_x = gs->scroll_start_y = -1;
 
@@ -482,6 +486,7 @@ gtk_gs_cleanup (GtkGS *gs)
 static void
 gtk_gs_interpreter_message(GtkGS *gs, gchar *msg, gpointer user_data)
 {
+        gdk_pointer_ungrab(GDK_CURRENT_TIME);
         if(strstr(msg, "Error:")) {
                 gs->gs_status = _("File is not a valid PostScript document.");
                 gtk_gs_cleanup(gs);
@@ -507,12 +512,6 @@ gtk_gs_destroy (GtkObject *object)
 		g_free(gs->input_buffer);
                 gs->input_buffer = NULL;
         }
-
-        if(gs->gconf_notify_id != -1) {
-                gconf_client_notify_remove(gtk_gs_defaults_gconf_client(),
-                                           gs->gconf_notify_id);
-                gs->gconf_notify_id = -1;
-        }
         if(gs->hadj) {
                 g_signal_handlers_disconnect_matched (G_OBJECT (gs->hadj),
                                                       G_SIGNAL_MATCH_DATA,
@@ -551,6 +550,7 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 		x = (gs->widget.allocation.width - gs->width)/2;
 		gs->hadj->value = 0.0;
 		gs->hadj->page_size = 1.0;
+                gs->hadj->step_increment = 1.0;
 	}
         else {
 		if (x > 0)
@@ -559,12 +559,14 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 			x = gs->widget.allocation.width - gs->width;
 		gs->hadj->page_size = ((gfloat) gs->widget.allocation.width)/gs->width;
                 gs->hadj->page_increment = gs->hadj->page_size*0.9;
+                gs->hadj->step_increment = 1.0/gs->width;
 		gs->hadj->value = -((gfloat)x)/gs->width;
 	}
 	if (gs->widget.allocation.height >= gs->height) {
 		y = (gs->widget.allocation.height - gs->height)/2;
 		gs->vadj->value = 0.0;
 		gs->vadj->page_size = 1.0;
+                gs->vadj->step_increment = 1.0;
 	}
         else {
 		if (y > 0)
@@ -573,13 +575,11 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 			y = gs->widget.allocation.height - gs->height;
 		gs->vadj->page_size = ((gfloat) gs->widget.allocation.height)/gs->height;
                 gs->vadj->page_increment = gs->vadj->page_size*0.9;
+                gs->vadj->step_increment = 1.0/gs->height;
 		gs->vadj->value = -((gfloat)y)/gs->height;
 	}
 
-	gdk_window_move(gs->pstarget, x, y);
-        while(gtk_events_pending()) {
-                gtk_main_iteration();
-        }
+        gdk_window_move(gs->pstarget, x, y);
 
 	gtk_adjustment_changed (gs->hadj);
 	gtk_adjustment_changed (gs->vadj);
@@ -681,8 +681,13 @@ gtk_gs_size_allocate (GtkWidget     *widget,
         /* 
          * update the adjustment if necessary (ie. a resize);
          */
-        if (GTK_WIDGET_REALIZED(gs)) {
-		gtk_gs_munge_adjustments (gs);
+        if (gs->zoom_mode == GTK_GS_ZOOM_ABSOLUTE) {
+                if (GTK_WIDGET_REALIZED(gs)) {
+                        gtk_gs_munge_adjustments (gs);
+                }
+        }
+        else {
+                gtk_gs_set_zoom(gs, 0.0);
         }
 
         gtk_gs_goto_page(gs, gs->current_page);
@@ -739,9 +744,6 @@ gtk_gs_value_adjustment_changed (GtkAdjustment *adjustment, gpointer data)
                 newy = -gs->vadj->value*gs->height;
 
         gdk_window_move(gs->pstarget, newx, newy);
-        while(gtk_events_pending()) {
-                gtk_main_iteration();
-        }
 }
 
 void
@@ -926,7 +928,7 @@ set_up_page (GtkGS *gs)
                             buf,
                             strlen(buf));
 
-        gdk_flush(); 
+        gdk_flush();
 }
 
 static void
@@ -1082,7 +1084,6 @@ input (gpointer data, gint source, GdkInputCondition condition)
         }
 }
 
-
 static int
 start_interpreter (GtkGS *gs)
 {
@@ -1112,7 +1113,7 @@ start_interpreter (GtkGS *gs)
         for(i = 0; i < NUM_GS_ARGS && gs_args[i]; i++, argc++)
                 argv[argc] = gs_args[i];
 
-        if(gs->antialiased ) {
+        if(gs->antialiased) {
                 if(strlen(gtk_gs_defaults_get_alpha_parameters()) == 0)
                         alpha_args = g_strsplit(ALPHA_PARAMS, " ",
                                                 NUM_ALPHA_ARGS);
@@ -1238,17 +1239,17 @@ start_interpreter (GtkGS *gs)
 static void
 stop_interpreter (GtkGS *gs)
 {
-        if (gs->interpreter_pid >= 0) {
+        if (gs->interpreter_pid > 0) {
                 int status = 0;
                 kill(gs->interpreter_pid, SIGTERM);
                 wait(&status);
+		gs->interpreter_pid = -1;
                 if(status == 1) {
                         gtk_gs_cleanup(gs);
                         gs->gs_status = _("Interpreter failed.");
                         g_signal_emit_by_name(G_OBJECT(gs), "interpreter_error",
                                               status);
                 }
-		gs->interpreter_pid = -1;
 	}
 
 	if (gs->interpreter_input >= 0) {
@@ -1405,8 +1406,8 @@ check_pdf (GtkGS *gs)
                 }
                 close(fd);
 		fname = ggv_quote_filename (filename);
-		cmd = g_strdup_printf (gtk_gs_defaults_get_scan_pdf_cmd(),
-                                       fname, filename_dsc);
+		cmd = g_strdup_printf (gtk_gs_defaults_get_convert_pdf_cmd(),
+                                       filename_dsc, fname);
 		g_free (fname);
 		/* this command (sometimes?) prints error messages to stdout! */
 		cmdline = g_strdup_printf ("%s >%s 2>&1", cmd, filename_err);
@@ -1420,7 +1421,7 @@ check_pdf (GtkGS *gs)
 		} else {
 			/* report error */
 			g_snprintf (buf, 1024,
-				    _("Error while scanning pdf file %s:\n"),
+				    _("Error while converting pdf file %s:\n"),
                                     filename);
 			gtk_gs_emit_error_msg (gs, buf);
 
@@ -1583,7 +1584,7 @@ GType gtk_gs_get_type (void)
                                         NULL, /* class_data */
                                         sizeof (GtkGS),
                                         0, /* n_preallocs */
-                                        (GtkObjectInitFunc) gtk_gs_init
+                                        (GInstanceInitFunc) gtk_gs_init
                                         };
 
                 gs_type = g_type_register_static(gtk_widget_get_type (),
@@ -1604,7 +1605,7 @@ gtk_gs_new (GtkAdjustment *hadj, GtkAdjustment *vadj)
         g_return_val_if_fail(hadj != NULL, NULL);
         g_return_val_if_fail(vadj != NULL, NULL);
 
-	gs = gtk_type_new(gtk_gs_get_type());
+	gs = (GtkGS *)gtk_type_new(gtk_gs_get_type());
 
         gtk_gs_set_adjustments(gs, hadj, vadj);
 
@@ -1660,11 +1661,8 @@ gtk_gs_center_page(GtkGS *gs)
 	g_return_if_fail (GTK_IS_GS(gs));
 
         gdk_window_move(gs->pstarget,
-                        (gs->widget.allocation.width - gs->width)/2,
-                        (gs->widget.allocation.height - gs->height)/2);
-        while(gtk_events_pending()) {
-                gtk_main_iteration();
-        }
+                         (gs->widget.allocation.width - gs->width)/2,
+                         (gs->widget.allocation.height - gs->height)/2);
         gs->hadj->page_size = ((gfloat) gs->widget.allocation.width)/gs->width;
         gs->hadj->page_size = MIN(gs->hadj->page_size, 1.0);
         gs->vadj->page_size = ((gfloat) gs->widget.allocation.height)/gs->height;
@@ -1718,6 +1716,7 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
 	if (fname == NULL) {
                 if(gdk_window_is_visible(gs->pstarget))
                         gdk_window_hide(gs->pstarget);
+                gs->gs_status = "";
 		return FALSE;
 	}
 
@@ -1949,6 +1948,9 @@ gtk_gs_goto_page (GtkGS *gs, gint page)
                    the last page of the file was displayed. In that
                    case, ggv restarts GS again and the first page is displayed.
                 */
+                if (page == gs->current_page && !gs->changed)
+                        return TRUE;
+
                 if(!GTK_WIDGET_REALIZED(gs))
                         return FALSE;                   
 
@@ -1983,7 +1985,7 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
         g_return_val_if_fail(GTK_IS_GS(gs), FALSE);
 
         if(new_pagesize == -1) {
-                if(gs->default_size >= 0)
+                if(gs->default_size > 0)
                         new_pagesize = gs->default_size;
                 if (!gs->override_size && gs->doc) {
                         /* If we have a document:
@@ -2016,12 +2018,8 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
         }
 
         /* Compute bounding box */
-        if (!gs->doc) {
-                new_llx = new_lly = 0;
-                new_urx = papersizes[new_pagesize].width;
-                new_ury = papersizes[new_pagesize].height;
-        }
-        else if ((gs->doc->epsf && !gs->override_size) || new_pagesize == -1) { /* epsf or bbox */
+        if (gs->doc &&
+            ((gs->doc->epsf && !gs->override_size) || new_pagesize == -1)) { /* epsf or bbox */
                 if((pageid >= 0) &&
                    (gs->doc->pages) &&
                    (gs->doc->pages[pageid].boundingbox[URX] > gs->doc->pages[pageid].boundingbox[LLX]) &&
@@ -2040,11 +2038,12 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
                         new_urx = gs->doc->boundingbox[URX];
                         new_ury = gs->doc->boundingbox[URY];
                 }
-                new_pagesize = gs->default_size;
         }
         else {
+                if(new_pagesize < 0)
+                        new_pagesize = gs->default_size;
                 new_llx = new_lly = 0;
-                if (!gs->override_size && gs->doc->size &&
+                if (gs->doc && !gs->override_size && gs->doc->size &&
                     (new_pagesize < gs->doc->numsizes)) {
                         new_urx = gs->doc->size[new_pagesize].width;
                         new_ury = gs->doc->size[new_pagesize].height;
@@ -2055,12 +2054,12 @@ gtk_gs_set_page_size(GtkGS *gs, gint new_pagesize, gint pageid)
         }
 
         if(new_urx <= new_llx)
-                new_urx = papersizes[8].width;
+                new_urx = papersizes[12].width;
         if(new_ury <= new_lly)
-                new_ury = papersizes[8].height;
+                new_ury = papersizes[12].height;
 
         /* If bounding box changed, setup for new size. */
-                /* gtk_gs_disable_interpreter (gs); */
+        /* gtk_gs_disable_interpreter (gs); */
         if ((new_llx != gs->llx) || (new_lly != gs->lly) ||
             (new_urx != gs->urx) || (new_ury != gs->ury)) {
                 gs->llx = new_llx;
@@ -2141,13 +2140,28 @@ gtk_gs_set_zoom (GtkGS *gs, gfloat zoom) {
         g_return_if_fail(gs != NULL);
         g_return_if_fail(GTK_IS_GS(gs));
 
-        if (gs->zoom_factor != zoom) { 
+        switch(gs->zoom_mode) {
+        case GTK_GS_ZOOM_FIT_WIDTH:
+                zoom = gtk_gs_zoom_to_fit(gs, TRUE);
+                break;
+        case GTK_GS_ZOOM_FIT_PAGE:
+                zoom = gtk_gs_zoom_to_fit(gs, FALSE);                
+                break;
+        case GTK_GS_ZOOM_ABSOLUTE:
+        default:
+                break;
+        }
+        if(zoom < ggv_zoom_levels[0])
+                zoom = ggv_zoom_levels[0];
+        else if(zoom > ggv_zoom_levels[ggv_max_zoom_levels])
+                zoom = ggv_zoom_levels[ggv_max_zoom_levels];
+        if (fabs(gs->zoom_factor - zoom) > 0.001) { 
                 gs->zoom_factor = zoom;
                 if (GTK_WIDGET_REALIZED(gs)) 
                         set_up_page(gs);
                 gs->changed = TRUE;
+                gtk_widget_queue_resize (&(gs->widget));
         }
-	gtk_widget_queue_resize (&(gs->widget));
 }
 
 gfloat
@@ -2220,9 +2234,15 @@ gtk_gs_get_orientation(GtkGS *gs)
 	g_return_val_if_fail(gs != NULL, -1);
 	g_return_val_if_fail(GTK_IS_GS(gs), -1);
 
-        if(gs->doc && gs->structured_doc) {
-                if(gs->doc->pages[MAX(gs->current_page, 0)].orientation != GTK_GS_ORIENTATION_NONE)
-                        gs->real_orientation = gs->doc->pages[MAX(gs->current_page, 0)].orientation;
+        if(gs->doc) {
+                if(gs->structured_doc) {
+                        if(gs->doc->pages[MAX(gs->current_page, 0)].orientation != GTK_GS_ORIENTATION_NONE)
+                                gs->real_orientation = gs->doc->pages[MAX(gs->current_page, 0)].orientation;
+                        else gs->real_orientation = gs->doc->default_page_orientation;
+                }
+        
+                if(gs->real_orientation == GTK_GS_ORIENTATION_NONE)
+                        gs->real_orientation = gs->doc->orientation;
         }
 
         if (gs->override_orientation ||
@@ -2363,7 +2383,7 @@ gtk_gs_get_document_page_label(GtkGS *widget, int page)
 }
 
 gint
-gtk_gs_get_size_index(gchar *string, GtkGSPaperSize *size)
+gtk_gs_get_size_index(const gchar *string, GtkGSPaperSize *size)
 {
         guint idx = 0;
 
@@ -2497,9 +2517,9 @@ gtk_gs_scroll_step(GtkGS *gs, GtkScrollType direction, gboolean dowrap)
 
         /* To make code more readable, we make a macro */
 #define ADVANCE_TOWARDS_LOWER(adj) \
-        (adj->value -= 0.75 * (adj->page_size))
+        (adj->value -= gs->scroll_step * (adj->page_size))
 #define ADVANCE_TOWARDS_UPPER(adj) \
-        (adj->value += 0.75 * (adj->page_size))
+        (adj->value += gs->scroll_step * (adj->page_size))
 
 #define ADVANCE_STEP(adj,dir) \
         (dir?ADVANCE_TOWARDS_UPPER(adj):ADVANCE_TOWARDS_LOWER(adj))
@@ -2583,7 +2603,7 @@ gtk_gs_get_postscript(GtkGS *gs, gint *pages)
         gboolean free_pages = FALSE;
 
         if(pages == NULL) {
-                if(gs->doc->epsf) {
+                if(!gs->structured_doc) {
                         FILE *f;
                         struct stat sb;
 
@@ -2667,6 +2687,7 @@ gtk_gs_set_adjustments (GtkGS         *gs,
                 hadj->upper = 1.0;
                 hadj->value = 0.0;
                 hadj->page_size = 1.0;
+                hadj->page_increment = 1.0;
                 gs->hadj = hadj;
                 gtk_object_ref (GTK_OBJECT (gs->hadj));
                 gtk_object_sink (GTK_OBJECT (gs->hadj));
@@ -2680,6 +2701,7 @@ gtk_gs_set_adjustments (GtkGS         *gs,
                 vadj->upper = 1.0;
                 vadj->value = 0.0;
                 vadj->page_size = 1.0;
+                vadj->page_increment = 1.0;
                 gs->vadj = vadj;
                 gtk_object_ref (GTK_OBJECT (gs->vadj));
                 gtk_object_sink (GTK_OBJECT (gs->vadj));
@@ -2692,3 +2714,30 @@ gtk_gs_set_adjustments (GtkGS         *gs,
                 gtk_gs_munge_adjustments(gs);
 }
 
+
+void
+gtk_gs_set_scroll_step(GtkGS *gs, gfloat scroll_step)
+{
+	gs->scroll_step = scroll_step;
+}
+
+gfloat
+gtk_gs_get_scroll_step(GtkGS *gs)
+{
+	return gs->scroll_step;
+}
+
+void
+gtk_gs_set_zoom_mode(GtkGS *gs, GtkGSZoomMode zoom_mode)
+{
+        if(zoom_mode != gs->zoom_mode) {
+                gs->zoom_mode = zoom_mode;
+                gtk_gs_set_zoom(gs, 1.0);
+        }
+}
+
+GtkGSZoomMode
+gtk_gs_get_zoom_mode(GtkGS *gs)
+{
+        return gs->zoom_mode;
+}
